==> hoteldruid-mod-pt_2.1.3-2.tar.gz: pt/visualizza_contratto.php <==
<?php

switch ($messaggio) {

case "via":  				$messaggio = "rua"; break;
case "Torna indietro":  		$messaggio = "Voltar"; break;
case "Da":  				$messaggio = "De"; break;
case "A":  				$messaggio = "Para"; break;
case "Oggetto":  			$messaggio = "Assunto"; break;
case "Allega":  			$messaggio = "Anexar"; break;
case "Spedisci":  			$messaggio = "Enviar"; break;
case "L'email a":  			$messaggio = "O e-mail para"; break;
case "è stata inviata":  		$messaggio = "foi enviada"; break;
case "bcc a":  				$messaggio = "cópia oculta bcc para"; break;
case "Non si è potuto inviare l'email a":	$messaggio = "Não foi possível enviar o e-mail para"; break;
case "documento":  			$messaggio = "documento"; break;
case "<span class=\"colblu\">salvato</span> come":	$messaggio = "<span class=\"colblu\">salvo</span> como"; break;
case "Cancella il documento":  		$messaggio = "Apagar o documento"; break;
case "Cancella i documenti":  		$messaggio = "Apagar os documentos"; break;
case "Il documento":  			$messaggio = "O documento"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":	$messaggio = "foi <b style=\"font-weight: normal; color: blue;\">apagado</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":	$messaggio = "Transação <font color=\"red\">expirada</font>"; break;
case "Sovrascrivi":  			$messaggio = "Sobrescrever"; break;
case "Documenti già esistenti riguardanti questa prenotazione":	$messaggio = "Já existem documentos em relação com esta reserva"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":	$messaggio = "Já existem documentos em relação com estas reservas"; break;
case "Salva dei nuovi documenti":  	$messaggio = "Salvar novos documentos"; break;
case "Salva un nuovo documento":  	$messaggio = "Salvar um novo documento"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":	$messaggio = "<span class=\"colblu\">Atenção</span>: um e-mail com o mesmo assunto já foi enviado ao cliente"; break;
case "Errore":  			$messaggio = "Erro"; break;
case "ha scritto":  			$messaggio = "escreveu"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>

==> hoteldruid-mod-pt_3.0.8-1.tar.gz: pt/visualizza_contratto.php <==
<?php

switch ($messaggio) {

case "via":  				$messaggio = "rua"; break;
case "Torna indietro":  		$messaggio = "Voltar"; break;
case "Da":  				$messaggio = "De"; break;
case "A":  				$messaggio = "Para"; break;
case "Oggetto":  			$messaggio = "Assunto"; break;
case "Allega":  			$messaggio = "Anexar"; break;
case "Spedisci":  			$messaggio = "Enviar"; break;
case "L'email a":  			$messaggio = "O e-mail para"; break;
case "è stata inviata":  		$messaggio = "foi enviada"; break;
case "bcc a":  				$messaggio = "cópia oculta bcc para"; break;
case "Non si è potuto inviare l'email a":	$messaggio = "Não foi possível enviar o e-mail para"; break;
case "documento":  			$messaggio = "documento"; break;
case "<span class=\"colblu\">salvato</span> come":	$messaggio = "<span class=\"colblu\">salvo</span> como"; break;
case "Cancella il documento":  		$messaggio = "Apagar o documento"; break;
case "Cancella i documenti":  		$messaggio = "Apagar os documentos"; break;
case "Il documento":  			$messaggio = "O documento"; break;
case "è stato <b style=\"font-weight: normal; color: blue;\">cancellato</b>":	$messaggio = "foi <b style=\"font-weight: normal; color: blue;\">apagado</b>"; break;
case "Transazione <font color=\"red\">scaduta</font>":	$messaggio = "Transação <font color=\"red\">expirada</font>"; break;
case "Sovrascrivi":  			$messaggio = "Sobrescrever"; break;
case "Documenti già esistenti riguardanti questa prenotazione":	$messaggio = "Já existem documentos em relação com esta reserva"; break;
case "Documenti già esistenti riguardanti queste prenotazioni":	$messaggio = "Já existem documentos em relação com estas reservas"; break;
case "Salva dei nuovi documenti":  	$messaggio = "Salvar novos documentos"; break;
case "Salva un nuovo documento":  	$messaggio = "Salvar um novo documento"; break;
case "<span class=\"colblu\">Attenzione</span>: una email con lo stesso oggetto è già stata inviata al cliente":	$messaggio = "<span class=\"colblu\">Atenção</span>: um e-mail com o mesmo assunto já foi enviado ao cliente"; break;
case "Errore":  			$messaggio = "Erro"; break;
case "ha scritto":  			$messaggio = "escreveu"; break;
case "in data":  			$messaggio = "on"; break;
case "Non si è potuto mascherare il mittente dell'email perchè attualmente <b class=\"colwarn\">SPF non è configurato correttamente</b> sul dominio della email":	$messaggio = "O remetente do e-mail não pôde ser mascarado porque <b class=\"colwarn\">SPF não está actualmente configurado correctamente</b> no domínio do e-mail"; break;
case "L'utente amministratore può cambiare questa inpostazione in":	$messaggio = "O usuário administrador pode alterar esta configuração para"; break;
case "configura e personalizza":  	$messaggio = "configurar e personalizar"; break;
case "È stato raggiunto il numero massimo di email giornaliere":	$messaggio = "O número máximo de e-mails diários foi atingido"; break;
case "Per mandare altre email l'utente amministratore può impostare un server remoto in":	$messaggio = "Para enviar mais e-mails, o usuário administrador pode configurar um servidor remoto em"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)



?>
